import { Utilities } from '@/util/Utilities';
import {
    Button, Modal, Select, TextInput, Text, ModalService, Form, LoadingService, DialogService, Footer, Tabs,
} from '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class Sm00001001DocumentoPropostaController {
    public tekgridDocumentoPropostaVisivel: boolean = true;

    public currentRow: any = {};

    private basicModal!: Modal;

    public abrirFrameDocumentoProposta({ row }: any) {
        this.tekgridDocumentoPropostaVisivel = false;
        this.currentRow = row;
        const tabs = Metadata.getInstance<Tabs>('tabsInformationDocumentoProposta');
        // tabs.activeTab = 0;
        this.carregarTabsDocumentoProposta({ component: tabs });
    }

    public openFilterDocumentoProposta({ component }: any) {
        const filterButton = Metadata.getInstance<Button>(`${component.name}_filterButton`);
        filterButton.click({} as Event, {} as HTMLElement);
    }

    public carregarTabsDocumentoProposta({ component }: any) {
        const tabAtiva = component.activeTab;
        const footer = Metadata.getInstance<Footer>('exampleFooterTabDocumentoProposta');

        if (component.tabs[tabAtiva].name === 'tab_documentoProposta') {
            this.carregarDadosAbaDocumentoProposta();
            footer.isVisible = true;
        } else if (component.tabs[tabAtiva].name === 'tab_anexosDocumentoProposta') {
            this.carregarDadosAbaAnexoDocumentoProposta();
            footer.isVisible = false;
        }
    }

    public carregarDadosAbaDocumentoProposta() {
        Metadata.getInstance<TextInput>('formDadosPropostaDocumentoProposta-NMPROPOSTA').value = this.currentRow.NMPROPOSTA;
        Metadata.getInstance<TextInput>('formDadosPropostaDocumentoProposta-NMPRINCIPALPARC').value = this.currentRow.NMPRINCIPALPARC;
        const textIDSITUACAOATUALORCAMENTO = this.currentRow.IDSITUACAOATUALORCAMENTO;
        switch (textIDSITUACAOATUALORCAMENTO) {
            case 'ELABORACAO':
                Metadata.getInstance<TextInput>('formDadosPropostaDocumentoProposta-IDSITUACAOATUALORCAMENTO').value = 'Em Elaboração';
                break;
            case 'CANCELADO':
                Metadata.getInstance<TextInput>('formDadosPropostaDocumentoProposta-IDSITUACAOATUALORCAMENTO').value = 'Cancelada';
                break;
            case 'CONCLUIDO':
                Metadata.getInstance<TextInput>('formDadosPropostaDocumentoProposta-IDSITUACAOATUALORCAMENTO').value = 'Concluída';
                break;
            case 'ACEITO':
                Metadata.getInstance<TextInput>('formDadosPropostaDocumentoProposta-IDSITUACAOATUALORCAMENTO').value = 'Aceita';
                break;
            default:
                break;
        }
        Metadata.getInstance<TextInput>('formDadosDocumentoProposta-DSMODELODOCORCA').value = this.currentRow.DSMODELODOCORCA;
        Metadata.getInstance<TextInput>('formDadosDocumentoProposta-NMTIPOORCAMENTO').value = this.currentRow.NMTIPOORCAMENTO;
        Metadata.getInstance<TextInput>('formDadosDocumentoProposta-VRTAMANHOLOGO').value = this.currentRow.VRTAMANHOLOGO;
        Metadata.getInstance<Select>('formDadosDocumentoProposta-IDSITUACAOORCAMENTO').value = this.currentRow.IDSITUACAOORCAMENTO;
    }

    public carregarDadosAbaAnexoDocumentoProposta() {
        const nrseqorcadoc = this.currentRow.NRSEQORCADOC;
        try {
            const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-anexos-documento-proposta');
            grid.datasource.setFilter({
                NRSEQORCADOC: nrseqorcadoc,
            });
        } catch (e) {
            // console.error(e);
        }
    }

    public voltarTekGridDocumentoProposta() {
        this.tekgridDocumentoPropostaVisivel = true;
    }

    get textFrameDocumentoProposta() {
        return this.currentRow.NMPROPOSTA;
    }

    get formDocumentoPropostaVisivel() {
        return !this.tekgridDocumentoPropostaVisivel;
    }

    public fecharModalInsercaoDocumentoProposta() {
        this.basicModal.hide();
        this.basicModal?.destroy();
    }

    public async abrirModalInsercaoDocumentoProposta() {
        await this.exibirModalInsercaoDocumentoProposta();
        Metadata.getInstance<Text>('titleText').text = 'Novo Documento de Contrato';
    }

    public async exibirModalInsercaoDocumentoProposta() {
        this.basicModal = await ModalService.createFromJson('sm_00001_001_documento_proposta/modal/sm_00001_001_insercao_documento_proposta', true);
        this.basicModal.show();
    }

    public setFilterCamposModalInsert({ component }: any) {
        const nrseqorcamento = this.currentRow.NRSEQORCAMENTO;
        try {
            component.datasource.setFilter({
                NRSEQORCAMENTO: nrseqorcamento,
            });
        } catch (e) {
            // console.error(e);
        }
    }

    public setModalInsertDocumentoContrato({ component }: any) {
        const nrseqorcamento = component.value;
        component.datasource.data.forEach((dados: any) => {
            if (dados.NRSEQORCAMENTO === nrseqorcamento || nrseqorcamento !== null) {
                Metadata.getInstance<TextInput>('formDadosPropostaModalDocumentoProposta-NMPRINCIPALPARC').value = dados.NMPRINCIPALPARC;
                const textSituacao = dados.IDSITUACAOATUALORCAMENTO;
                switch (textSituacao) {
                    case 'ELABORACAO':
                        Metadata.getInstance<TextInput>('formDadosPropostaModalDocumentoProposta-IDSITUACAOATUALORCAMENTO').value = 'Em Elaboração';
                        break;
                    case 'CANCELADO':
                        Metadata.getInstance<TextInput>('formDadosPropostaModalDocumentoProposta-IDSITUACAOATUALORCAMENTO').value = 'Cancelada';
                        break;
                    case 'CONCLUIDO':
                        Metadata.getInstance<TextInput>('formDadosPropostaModalDocumentoProposta-IDSITUACAOATUALORCAMENTO').value = 'Concluída';
                        break;
                    case 'ACEITO':
                        Metadata.getInstance<TextInput>('formDadosPropostaModalDocumentoProposta-IDSITUACAOATUALORCAMENTO').value = 'Aceita';
                        break;
                    default:
                        break;
                }
            } else {
                Metadata.getInstance<TextInput>('formDadosPropostaModalDocumentoProposta-NMPRINCIPALPARC').value = null;
                Metadata.getInstance<TextInput>('formDadosPropostaModalDocumentoProposta-IDSITUACAOATUALORCAMENTO').value = null;
            }
        });
    }

    public salvarDocumentoProposta() {
        const formProposta = Metadata.getInstance<Form>('formDadosPropostaModalDocumentoProposta');
        const formDocumento = Metadata.getInstance<Form>('formDadosDocumentoModalProposta');
        const grid = Metadata.getInstance<TekGrid>('tek-grid-documento_proposta_grid');
        const params = {
            NRSEQORCAMENTO: Metadata.getInstance<Select>('formDadosPropostaModalDocumentoProposta-NMPROPOSTA').value,
            NRTIPOORCAMENTO: Metadata.getInstance<Select>('formDadosDocumentoModalProposta-NMTIPOORCAMENTO').value,
            VRTAMANHOLOGO: Metadata.getInstance<TextInput>('formDadosDocumentoModalProposta-VRTAMANHOLOGO').value,
            IDSITUACAOORCAMENTO: Metadata.getInstance<Select>('formDadosDocumentoModalProposta-IDSITUACAOORCAMENTO').value,
            NRSEQMODDOCFCT: Metadata.getInstance<Select>('formDadosDocumentoModalProposta-DSMODELODOCORCA').value,
        };
        if (Utilities.validateForm(formProposta) && Utilities.validateForm(formDocumento)) {
            LoadingService.show();
            Http.post('/inserirDocumentoProposta', params).then(() => {
                this.fecharModalInsercaoDocumentoProposta();
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public showConfirmDeleteMessageProposta({ event }: any) {
        event!.preventDefault();
        DialogService.show({
            name: 'buttons-dialog-documento-proposta',
            type: 'warning',
            title: 'Excluir Registro',
            text: 'Deseja realmente excluir todos os registros selecionados?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deleteDocumentoProposta();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public deleteDocumentoProposta() {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-documento_proposta_grid');
        LoadingService.show();
        Http.post('/deleteDocumentoProposta', grid.selectedRows)
            .then(() => {
                grid.selectedRows = [];
                grid.reload();
                Utilities.showSuccessMessage();
            }).catch((error) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
    }
}
